@@ -39,6 +39,8 @@ app.register.controller('helpCtrl', ['$rootScope','$scope','$timeout',
 						$rootScope.deviceInfo.type == "WS-C3560CX-8XPD-S" || $rootScope.deviceInfo.type == "WS-C3560CX-8PT-S" ||
 						$rootScope.deviceInfo.type == "WS-C2960CPD-8PT-L" ){
 							imageName=dir+"/"+ $rootScope.deviceInfo.type + ".jpg";
+					}else if($rootScope.deviceInfo.type.indexOf("2960+")!=-1){
+						imageName=dir+"/"+platform+"P.jpg";
 					} else {
 						imageName=dir+"/"+platform+".jpg";
 					}
