@@ -1,5 +1,5 @@
 /**
- Description: Controller for Trouble Shooting
+ Description: Controller for Netflow
  Copyright (c) 2016 by Cisco Systems, Inc.
  All rights reserved.
  */
@@ -7,8 +7,7 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
 	function($scope,$rootScope,$timeout, $filter, gridCrudService,requestRoutingService,dataSourceService,dialogService,notificationService,executeCliCmdService,validationService,getStringLineService) {
 		var trimVal=$filter('trimValue');
 		var translate = $filter("translate");
-		var versionInfo = requestRoutingService.getShowCmdOutput("show version","overviewshVer");
-        var deviceType = versionInfo.ShowVersion.name;
+		var deviceType = $rootScope.deviceInfo.type;
 		// $scope Variables are declared using angular.extend method.
 		angular.extend($scope, {
 			netFlowTemplateDataSource: [{nftText: translate("nft_application"), nftValue:'defaultApplicationTraffic', nftShort:'dat'},
@@ -36,7 +35,8 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
             enableDeleteBtn: true,
             fullNetFlowSupport:false
 		});
-
+		angular.element(".btnView").hide();
+		angular.element(".pageLoader").show();
 		// Find the current Device
 		if(deviceType.indexOf("2960X") != -1 || deviceType.indexOf("2960XR") != -1 || deviceType.indexOf("3560CX") != -1){
 			var fullNetFlow = {samplingMethodText: translate("nf_sampling_fullnetflow"), samplingMethodValue:'fullnetflow'};
@@ -120,7 +120,8 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
 					  morePages: translate("com_page_morePage")
 				},
 				refresh: false,
-                pageSizes: gridCrudService.grid_page_sizes, // This page size variable is written in datasourceService.js file.
+                // This page size variable is written in datasourceService.js file.
+                pageSizes: gridCrudService.grid_page_sizes,
                 buttonCount: 4
             },
             filterable : {
@@ -167,28 +168,94 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
                 }
             ]
         };
-        $scope.loadGridData = function () {
+    //Initial load function for this controller
+       $scope.loadGridData = function () {
+        	var netFlowCLI="show flow monitor\n show flow interface\n show running-config | section interface\n show flow exporter\n show sampler\n";
+        	var netFlowCLIOP = deviceCommunicatorCLI.getExecCmdOutput(netFlowCLI);
+           	//Filling the interface drop down
+       		var showInterfaces=[];
+    		var interfacesRunningConfig=netFlowCLIOP[2].split("interface");
+    		for(var i = 1; i < interfacesRunningConfig.length; i++){
+    			var intObj={};
+    			intShowRun="interface "+interfacesRunningConfig[i];
+                arrIntShowRun=	intShowRun.split("\n");
+				if( arrIntShowRun[0].indexOf("Ethernet")!=-1 || arrIntShowRun[0].indexOf("Te")!=-1|| arrIntShowRun[0].indexOf("Bluetooth")!=-1 || arrIntShowRun[0].indexOf("Loopback")!=-1 || arrIntShowRun[0].indexOf("Vlan")!=-1){
+					intObj["interfaceName"]= executeCliCmdService.getNextString(intShowRun,["interface"],["\n"]).trim();
+					intObj["ipAddress"]= executeCliCmdService.getNextString(intShowRun,["ip address"],["\n"]).trim().split(" ")[0];
+					showInterfaces.push(intObj);
+				}
+    		}
+    		//Setting show flow exporter list
+    		var showFlowExporterList=[];
+    		var exporterDetails="";
+    		var showFlowOP=netFlowCLIOP[3].split("Flow Exporter");
+    		for(var i = 1; i < showFlowOP.length; i++){
+    			var expoterObj={};
+    			exporterDetails="Flow Exporter "+showFlowOP[i];
+    			expoterObj["exporterName"]= executeCliCmdService.getNextString(exporterDetails,["Flow Exporter"],[":"]).trim();
+    			expoterObj["collectorIpAddress"]= executeCliCmdService.getNextString(exporterDetails,["Destination IP address:"],["\n"]).trim();
+    			expoterObj["switchIpAddress"]= executeCliCmdService.getNextString(exporterDetails,["Source IP address:"],["\n"]).trim();
+    			expoterObj["interface"]= executeCliCmdService.getNextString(exporterDetails,["Source Interface:"],["\n"]).trim();
+    			showFlowExporterList.push(expoterObj);
+    		}
+            //Setting show sampler list
+            var showSamplerList=[];
+            var samplerDetails="";
+            var showsamplerOP=netFlowCLIOP[4].split("Sampler");
+            for(var i = 1; i < showsamplerOP.length; i++){
+                var samplerObj={};
+                samplerDetails="Sampler "+showsamplerOP[i];
+                samplerObj["samplerName"]= executeCliCmdService.getNextString(samplerDetails,["Sampler"],[":"]).trim();
+                samplerObj["samplerType"]= executeCliCmdService.getNextString(samplerDetails,["Type:"],["\n"]).trim();
+                showSamplerList.push(samplerObj);
+            }
+            angular.forEach(showInterfaces, function (inter) {
+                if (inter.interfaceName.indexOf("TenGigabitEthernet") != -1) {
+                    inter.interfaceName = inter.interfaceName.replace("TenGigabitEthernet", "Te");
+                } else if (inter.interfaceName.indexOf("FastEthernet") != -1) {
+                    inter.interfaceName = inter.interfaceName.replace("FastEthernet", "Fa");
+                } else if (inter.interfaceName.indexOf("GigabitEthernet") != -1) {
+                    inter.interfaceName = inter.interfaceName.replace("GigabitEthernet", "Gi");
+                } else if (inter.interfaceName.indexOf("Bluetooth") != -1) {
+                    inter.interfaceName = inter.interfaceName.replace("Bluetooth", "Bl");
+                } else if (inter.interfaceName.indexOf("Loopback") != -1) {
+                    inter.interfaceName = inter.interfaceName.replace("Loopback", "Lo");
+                }
+                if(inter.ipAddress != 'unassigned' && inter.ipAddress != ""){
+    				var switchExportAddress = {
+        				"text": inter.interfaceName+"_"+inter.ipAddress,
+        				"ipAddress":inter.ipAddress,
+        				"name":inter.interfaceName
+        			};
+                    $scope.switchExportAddress.push(switchExportAddress);
+    			}
+                $scope.inputCaptureInterface.push(inter);
+    		});
+    		var min = 32, max = 1032;
+    		for (var i = min; i <= max; i++) {
+    			$scope.samplerMethodRange.push(""+i);
+    		}
 	        $scope.netFlowMonitorsGridData = new kendo.data.ObservableArray([]);
 	        //show flow monitor
 	        var showFlowInterface = "";
-	        var strCLIOutput = deviceCommunicator.getExecCmdOutput("show flow monitor");
+	        var strCLIOutput = netFlowCLIOP[0];
 	        var START_FLOW_MONITOR = ["Flow Monitor "];
 	        var START_FLOW_RECORD = ["Flow Record:"];
             var START_FLOW_EXPORTER = ["Flow Exporter:"];
 	        var END_FLOW_MONITOR = [":"];
 	        var END_OUTPUT = ["\n"];
 	        var arrFlowMonitor=strCLIOutput.split("Flow Monitor");
-            showFlowInterface = deviceCommunicator.getExecCmdOutput("show flow interface\n");
+            showFlowInterface =netFlowCLIOP[1];
             var showFlowIntSamplers = getStringLineService.getLines(showFlowInterface,['traffic(ip): ']);
-	    var ipv6Samplers = getStringLineService.getLines(showFlowInterface,['traffic(ipv6): ']);
+	        var ipv6Samplers = getStringLineService.getLines(showFlowInterface,['traffic(ipv6): ']);
             showFlowIntSamplers = showFlowIntSamplers.concat(ipv6Samplers);
             var showFlowIntMonitors = getStringLineService.getLines(showFlowInterface,['monitor: ']);
             var netFlowMonitorObj = {};
             var showRunConfigInterface = [];
             $scope.showFlowIntRecords = [];
             //Associated Interface values
-            var intStrCLIOutput = deviceCommunicator.getExecCmdOutput("show running-config | section interface");
-            var showRunConfigSecInterface = intStrCLIOutput.split("interface ");            
+            var intStrCLIOutput = netFlowCLIOP[2];
+            var showRunConfigSecInterface = intStrCLIOutput.split("interface ");
             for(var inter = 1; inter < showRunConfigSecInterface.length; inter++){
                 if(showRunConfigSecInterface[inter].indexOf("ip flow monitor")!=-1){
                     showRunConfigInterface.push(showRunConfigSecInterface[inter]);
@@ -206,9 +273,9 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
 	         		flowRecord = flowRecord.trim();
                 var flowExporter = executeCliCmdService.getNextString(flowMonitor,START_FLOW_EXPORTER,END_OUTPUT);
                 if(flowExporter !== ""){
-                    var flowExporterValue = flowExporter.trim().replace(/ *\([^)]*\) */g, "");  
+                    var flowExporterValue = flowExporter.trim().replace(/ *\([^)]*\) */g, "");
                     for(var shwInt = 0; shwInt < showFlowIntSamplers.length; shwInt++){
-			var showFlowIntSamplerNames = "";
+			            var showFlowIntSamplerNames = "";
                     	if(showFlowIntSamplers[shwInt].indexOf("traffic(ipv6):") != -1){
                     		showFlowIntSamplerNames = showFlowIntSamplers[shwInt].split("traffic(ipv6):")[1].trim();
                     	} else {
@@ -218,8 +285,9 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
                         if(showFlowIntMonitorNames === flowMonitorName){
                             if(showFlowIntSamplerNames.indexOf("sampler ")!=-1){
                                 var allSamplerNames = showFlowIntSamplerNames.split("sampler")[1].trim();
-                                var showSampler = requestRoutingService.getShowCmdOutput("show sampler "+allSamplerNames, "showSampler");
-                                netFlowMonitorObj.Sampling = showSampler.showsampler.samplerType;
+                                //find the show sampler index which is matched
+                                var findSamplerIndex = $filter('filter')(showSamplerList, {"samplerName":allSamplerNames},true);
+                                netFlowMonitorObj.Sampling = findSamplerIndex[0].samplerType;
                                 netFlowMonitorObj.samplingField = $filter('filter')($scope.samplingMethodDataSource, {"samplingMethodValue":netFlowMonitorObj.Sampling})[0].samplingMethodText;
                                 netFlowMonitorObj.SamplerName = allSamplerNames;
                             }else{
@@ -229,11 +297,11 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
                             }
                         }
                     }
-             		var netFlowTemplateTemp = $filter('filter')($scope.netFlowTemplateDataSource, {"nftValue":flowRecord})
-             			,showFlowExporter = requestRoutingService.getShowCmdOutput("show flow exporter "+flowExporterValue, "showFlowExporter")
-            			,shortNameOfNFTemplate = $filter('filter')($scope.netFlowTemplateDataSource, {"nftValue":flowRecord});                		
-                    if(showFlowExporter.showexporter.collectorIpAddress){
-                        netFlowMonitorObj.Collector = showFlowExporter.showexporter.collectorIpAddress;
+             		var netFlowTemplateTemp = $filter('filter')($scope.netFlowTemplateDataSource, {"nftValue":flowRecord});
+                    //find the showflow expoter index which is matching with the monitor flow exporter
+                    var findExporterIndex = $filter('filter')(showFlowExporterList, {"exporterName":flowExporterValue},true);
+                    if(findExporterIndex[0].collectorIpAddress){
+                        netFlowMonitorObj.Collector = findExporterIndex[0].collectorIpAddress;
                     }
                     if(netFlowTemplateTemp.length > 0){
         			    netFlowMonitorObj.NetflowTemplate =  netFlowTemplateTemp[0].nftText;
@@ -241,8 +309,8 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
 	        		netFlowMonitorObj.FlowRecord = flowRecord;
 	        		netFlowMonitorObj.FlowExporter = flowExporterValue;
 	        		netFlowMonitorObj.FlowMonitorName = flowMonitorName;
-	        		netFlowMonitorObj.Interface = showFlowExporter.showexporter.interface;
-	        		netFlowMonitorObj.Switch = showFlowExporter.showexporter.switchIpAddress;
+	        		netFlowMonitorObj.Interface = findExporterIndex[0].interface;
+	        		netFlowMonitorObj.Switch = findExporterIndex[0].switchIpAddress;
                     if(showRunConfigInterface.length > 0){
                         for(var cInter = 0; cInter < showRunConfigInterface.length; cInter++){
                             if(showRunConfigInterface[cInter].indexOf(netFlowMonitorObj.FlowMonitorName) !== -1){
@@ -258,7 +326,6 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
                                     intNames = intExtraHasNames[0];
                                 }
                                 netFlowMonitorObj.SamplerInterFaces = intNames;
-                                //break;
                             }else{
                                 netFlowMonitorObj.SamplerInterFaces = "";
                             }
@@ -273,9 +340,12 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
 				pageSize: 10,
 				data: $scope.netFlowMonitorsGridData
 			});
+			angular.element(".btnView").show();
+			angular.element(".pageLoader").hide();
         }
+       $scope.loadGridData();
         $scope.isChecked = function (checked, dataItem) {
-        	if (checked == false) {
+        	if (!checked) {
                 $scope.countNetFlow = $scope.countNetFlow - 1;
                 var index = $scope.selectedNetFlowMonitorsArray.indexOf(dataItem);
                 if (index > -1) {
@@ -293,7 +363,6 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
             }
         };
         $scope.rowSelected = function () {
-        	$scope.enableDeleteBtn = false;
 			$scope.disableApplyButton = true;
 			if ($scope.netFlowMonitorsGridDataSource.hasChanges() === false) {
                 $scope.disableApplyButton = false;
@@ -362,36 +431,6 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
 		$scope.$on("netFlowDeleteConfirmation", function() {
 			$scope.deleteBtnFunction($scope.dlgNetFlow.data("kendoWindow"));
 		});
-        $scope.netFlowInit = function(){
-        	var showInterfaces = requestRoutingService.getShowCmdOutput("show ip int brief", "showInterfaces");
-        		showInterfaces = showInterfaces.showIpInterfaceBrief.IntBriefTable.entry;
-                angular.forEach(showInterfaces, function(inter){
-                    if(inter.interfaceName.indexOf("TenGigabitEthernet")!=-1){
-                        inter.interfaceName = inter.interfaceName.replace("TenGigabitEthernet","Te");
-                    }else if(inter.interfaceName.indexOf("FastEthernet")!=-1){
-                        inter.interfaceName = inter.interfaceName.replace("FastEthernet","Fa");
-                    }else if(inter.interfaceName.indexOf("GigabitEthernet")!=-1){
-                        inter.interfaceName = inter.interfaceName.replace("GigabitEthernet","Gi");
-                    }
-                    if(inter.ipAddress != 'unassigned'){
-        				var switchExportAddress = {
-	        				"text": inter.interfaceName+"_"+inter.ipAddress,
-	        				"ipAddress":inter.ipAddress,
-	        				"name":inter.interfaceName
-	        			};
-                        $scope.switchExportAddress.push(switchExportAddress);
-        			}
-                    $scope.inputCaptureInterface.push(inter);
-        		});
-        		var min = 32, max = 1032;
-        	for (var i = min; i <= max; i++) {
-        		$scope.samplerMethodRange.push(""+i);
-		    }
-		    $scope.loadGridData();
-        }
-        //Initial load function for this controller
-        $scope.netFlowInit();
-
         $scope.fnCancel = function(){
             $scope.samplingMethodType = $scope.samplingMethodDataSource[0].samplingMethodValue;
             $scope.inputCapIntType = $scope.inputCaptureInterface[0].interfaceName;
@@ -399,7 +438,8 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
             $scope.collectorIpAddress = "";
             angular.element("#samplerRangeContainer input").val("");
             $timeout(function(){
-                netFlowFormValidations.hideMessages();//hiding the validator popup messges.
+                //hiding the validator popup messges.
+                netFlowFormValidations.hideMessages();
             },50)
         }
         $scope.manualGridRefresh = function(){
@@ -407,7 +447,7 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
             grid.dataSource = $scope.netFlowMonitorsGridDataSource;
             $scope.netFlowMonitorsGridDataSource.read();
             grid.refresh();
-        }        
+        }
         $scope.findCLICMDIsAlreadyExists = function(recordName, CLICommand){
             var recordCLI = deviceCommunicator.getExecCmdOutput(CLICommand);
             if(recordCLI.indexOf(recordName) !== -1){
@@ -515,7 +555,7 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
 		        		netFlowConfigCLI += "collect timestamp sys-uptime first \n";
 		        		netFlowConfigCLI += "collect timestamp sys-uptime last \n";
 		        		netFlowConfigCLI +=  "exit \n";
-		        	}		        	
+		        	}
 		        	var source_interface = $filter('filter')($scope.switchExportAddress, {"text":$scope.switchExportAddType})
 		        		,shortNameOfNFTemplate = $filter('filter')($scope.netFlowTemplateDataSource, {"nftValue":$scope.netFlowTemplateType})
 		        		,switchExportAddressToHex = $scope.convertIpAddressToHex(source_interface[0].ipAddress.toString())
@@ -527,18 +567,18 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
     		        	netFlowConfigCLI += "source "+source_interface[0].name+" \n";
     		        	netFlowConfigCLI +=  "transport udp 2055 \n";
     		        	netFlowConfigCLI +=  "exit \n";
-                    }		        	
+                    }
 		        	// CLI command for Sampling (Sampling Method)
                     if($scope.samplingMethodType !== "fullnetflow" && !samplerIsOneTime){
                         netFlowConfigCLI += "sampler "+$scope.samplingMethodType+"_1_"+$scope.samplingMethodRangeType+" \n";
     		        	netFlowConfigCLI += "mode "+$scope.samplingMethodType+" 1 out-of "+$scope.samplingMethodRangeType+" \n";
     		        	netFlowConfigCLI +=  "exit \n";
-                    }		        	
+                    }
 		        	//CLI command for Create a flow monitor
 		        	netFlowConfigCLI += "flow monitor "+$scope.monitorUnitName+shortNameOfNFTemplate[0].nftShort+"X"+source_interface[0].name.split("/").join("_")+"_"+switchExportAddressToHex+"_"+collectoIpAddressToHex+$scope.inputCapIntType.replace(/\//g,"_")+" \n";
 		        	netFlowConfigCLI += "exporter export_"+$scope.switchExportAddType.split("/").join("_")+"_"+$scope.collectorIpAddress+" \n";
 		        	netFlowConfigCLI += "record "+$scope.netFlowTemplateType+" \n";
-		        	netFlowConfigCLI += "exit \n";			        
+		        	netFlowConfigCLI += "exit \n";
                     //CLI command for Associate to an interface
 		    var ipType = ($scope.netFlowTemplateType.indexOf("CapacityPlanning")!=-1)?"ipv6":"ip";
                     if($scope.samplingMethodType !== "fullnetflow"){
@@ -564,7 +604,8 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
 		            $scope.collectorIpAddress = '';
 		            angular.element("#samplerRangeContainer input").val("");
 		            $timeout(function(){
-		            	netFlowFormValidations.hideMessages();//hiding the validator popup messges.
+                        //hiding the validator popup messges.
+		            	netFlowFormValidations.hideMessages();
 		            },10);
 	        	}else{
                     if(interfaceIsOneTime.length > 0){
@@ -572,5 +613,7 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
                     }
 	        	}
         	}
+			$scope.selectedNetFlowMonitorsArray = [];
+			$scope.enableDeleteBtn = true;
         }
 	}]);
