@@ -14,30 +14,38 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
         $scope.diableVStackApplyButton = true;
         var jumboVal = "10240";
         $scope.virtualStartCluster = "";
-        var versionInfo = requestRoutingService.getShowCmdOutput("show version","overviewshVer");
-        var deviceType = versionInfo.ShowVersion.name;
+        var deviceType = $rootScope.deviceInfo.type;
+		var oldClusterDomainName;
         $scope.isSelecon = false;
 		$scope.showBluetoothTab=true;
 		$scope.showBluetoothDetails=true;
-        /*Controller - Data & Actions For Switch Tab Starts*/
+		$scope.onClickstpTab = function(tab){
+			if(tab === 'switch'){
+				$scope.initGridLoad();
+			}
+			if(tab === 'stp'){
+				$scope.loadSTP();
+			}
+			if(tab === 'bluetooth'){
+				$scope.loadBlueTooth();
+			}
+		}
+/*Controller - Data & Actions For Switch Tab Starts*/
         var switchConfigDetails, switchInitialData,stackInitialData;
         if(deviceType.indexOf("CDB") != -1){
         	$scope.showSeleconDetails=true;
         	$scope.mtuSizeStatus=true;
 			$scope.isSelecon = true;
         }
-		if(deviceType.indexOf("2960C-") != -1 || deviceType.indexOf("2960+48TC-S") != -1){
+		if(deviceType.indexOf("2960C-") != -1 || deviceType.indexOf("2960+48TC-S") != -1 || deviceType.indexOf("2960+-48TC-S") != -1){
 			$scope.showBluetoothTab=false;
 			$scope.showBluetoothDetails=false;
         }
-
-        $scope.mtuSizeDataSource = dataSourceService.mtuSizeOptions();       
+        $scope.mtuSizeDataSource = dataSourceService.mtuSizeOptions();
 		    $rootScope.$watch('deviceInfo.stackingInfo', function(newVal){
-          stackInitialData = newVal.type;
+			stackInitialData = newVal.type;
         });
-		
-		/*LED status start Here*/ 
-		
+		/*LED status start Here*/
 		if(deviceType.indexOf("CDB") != -1){
 			$scope.stpLedTab = true;
 			$scope.imageON = false;
@@ -68,12 +76,11 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
 					$scope.ledHrDataSource.push(tempHr);
 				}
 				$scope.ledMinDataSource.push(tempMin);
-			}	
+			}
 		}
-		
 		$scope.ledStatusChange = function(){
 			$scope.diableApplyButton = false;
-		}			
+		}
 		$scope.toggleImage = function(){
 			$scope.enableApplybtnselecon();
 			$scope.imageOFF = !$scope.imageOFF;
@@ -84,8 +91,7 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
 				$scope.ledstatusDisable = true;
 			}
 		}
-		
-		/*LED status end Here*/ 
+		/*LED status end Here*/
         $scope.initGridLoad = function () {
            switchConfigDetails = stpdataSourceService.getSwitchDetails();
            //setting values
@@ -98,7 +104,7 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
                defaultGateway: switchConfigDetails.defaultGateway,
                switchCOAP:switchConfigDetails.switchCOAP
            };
-           $scope.diableApplyButton=true;		   
+           $scope.diableApplyButton=true;
 			if(deviceType.indexOf("2960L") != -1 || deviceType.indexOf("CDB")!=-1){
 				$scope.mtusizetype='1';
 				$timeout(function(){
@@ -113,16 +119,6 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
 				$scope.mtusizetype='2';
 				$scope.switchConfigData.mtuSize=switchConfigDetails.mtuSize;
 			}
-			if(deviceType.indexOf("2960C-") === -1 || deviceType.indexOf("2960+48TC-S") === -1){
-				$scope.diableblueApplyButton=true;
-				$scope.cancelblueButton = true;				
-				var bluetoothData = requestRoutingService.getShowCmdOutput("show running-config | section Bluetooth");
-				if(bluetoothData.indexOf("shutdown") != -1) {
-					$scope.switchConfigData.bluetoothstatus = translate("toggle_off");
-				}else {
-					$scope.switchConfigData.bluetoothstatus = translate("toggle_on");
-				}
-			}
 			if(deviceType.indexOf("CDB") != -1){
 				$scope.ledDayType = $scope.ledDayDataSource[0].ledDayValue;
 				$scope.ledHrType = $scope.ledHrDataSource[0].ledHrValue;
@@ -134,8 +130,7 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
 			}
 			switchInitialData = angular.copy(switchConfigDetails);
         };
-        $scope.initGridLoad();    
-
+        $scope.initGridLoad();
 		$scope.enableApplybtn = function(){
 			if((switchInitialData.hostName != $scope.switchConfigData.hostName) ||  (switchInitialData.switchIp != $scope.switchConfigData.switchIp) || (switchInitialData.subnetMask != $scope.switchConfigData.subnetMask) || (switchInitialData.defaultGateway != $scope.switchConfigData.defaultGateway) || (switchInitialData.managementVlan != $scope.switchConfigData.managementVlan) || (switchInitialData.mtuSize != $scope.switchConfigData.mtuSize) || (switchInitialData.switchCOAP != $scope.switchConfigData.switchCOAP) || ($scope.stpStackModeType != oldStpStackModeType) || (oldClusterDomainName != $scope.cluster.virtualDomainName)){
 				$scope.diableApplyButton = false;
@@ -143,7 +138,6 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
 				$scope.diableApplyButton = true;
 			}
 		}
-		
 		$scope.enableApplybtnselecon = function(){
 			if((switchInitialData.hostName != $scope.switchConfigData.hostName) ||  (switchInitialData.switchIp != $scope.switchConfigData.switchIp) || (switchInitialData.subnetMask != $scope.switchConfigData.subnetMask) || (switchInitialData.defaultGateway != $scope.switchConfigData.defaultGateway) || (switchInitialData.managementVlan != $scope.switchConfigData.managementVlan) || (switchInitialData.mtuSize != $scope.switchConfigData.mtuSize) || (switchInitialData.switchCOAP != $scope.switchConfigData.switchCOAP) || ($scope.stpStackModeType != oldStpStackModeType) || $scope.imageON == false){
 				$scope.diableApplyButton = false;
@@ -151,7 +145,6 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
 				$scope.diableApplyButton = true;
 			}
 		}
-		
         //validation
         var stpValidations = angular.element("#stpForm").kendoValidator({
             rules: {
@@ -211,7 +204,6 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
             if($scope.stpStackModeType == "CLUSTER"){
               if(input.val()==''){
                   return false;
-              }else{
               }
             }
               return true;
@@ -227,16 +219,13 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
 					return true;
 				}
           }
-        }).data("kendoValidator");        
-        /*Stacking Starts Here*/
+        }).data("kendoValidator");
+  /*Stacking Starts Here*/
 		var isPhysicalStackSupported = $rootScope.deviceInfo.isPhysicalStackSupported;
         var masterId = $rootScope.deviceInfo.masterId;
         if(isPhysicalStackSupported){
           $scope.showPhysicalStacking = true;
         }
-        var showClusterDetails = stpdataSourceService.getShowCluster();
-        $scope.hasCluster = showClusterDetails.ClusterDetails.data != "";
-
         $scope.updateStacking = function(){
           if(stackInitialData !== $scope.stpStackModeType){
             $scope.diableApplyButton = false;
@@ -268,14 +257,12 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
           },1000);
         }
         $scope.cluster = {};
-        var oldClusterDomainName;
         $scope.clusterConfig = function(){
             $scope.cluster.virtualDomainName = "";
-            showClusterDetails = stpdataSourceService.getShowCluster();
-            $scope.hasCluster = showClusterDetails.ClusterDetails.data != "";
-            if($scope.hasCluster){
-                $scope.virtualDomainName = showClusterDetails.ClusterDetails.data.domainName.replace(/"/gi, "");
-                $scope.cluster.virtualDomainName = showClusterDetails.ClusterDetails.data.domainName.replace(/"/gi, "");
+            var showClusterDetails = switchConfigDetails.domainName;
+            if(showClusterDetails!=""){
+                $scope.virtualDomainName = showClusterDetails.replace(/"/gi, "");
+                $scope.cluster.virtualDomainName = showClusterDetails.replace(/"/gi, "");
                 oldClusterDomainName = $scope.cluster.virtualDomainName;
             }
         }
@@ -324,14 +311,10 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
                 cliHostNameCmd+="no cluster run\n";
               }
             }
-
             return cliHostNameCmd;
           }
-          /*Stacking Ends Here*/
-		  
-		
-		  
-        //save switch config into device
+ /*Stacking Ends Here*/
+ //save switch config into device
         $scope.saveSwitchConfig = function () {
         	var cliHostNameCmd="";
             if (stpValidations.validate()) {
@@ -368,7 +351,11 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
                 }
         				if ($scope.switchConfigData.mtuSize !== switchInitialData.mtuSize) {
         					if(parseInt($scope.switchConfigData.mtuSize) > 1998){
-        						cliHostNameCmd+="system mtu jumbo "+$scope.switchConfigData.mtuSize+"\n";
+								if(deviceType.indexOf("2960L")!=-1){
+									cliHostNameCmd+="system mtu "+$scope.switchConfigData.mtuSize+"\n";
+								}else{
+									cliHostNameCmd+="system mtu jumbo "+$scope.switchConfigData.mtuSize+"\n";
+								}
         					}else{
         						cliHostNameCmd+="system mtu "+$scope.switchConfigData.mtuSize+"\n";
         					}
@@ -382,7 +369,7 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
 	                }else{
 	                	cliHostNameCmd+="coap proxy \n stop \n no coap proxy \n";
 	                }
-                }				        
+                }
           		 var selectedStackingOption = $filter('filter')($scope.stpStackModeDataSource, $scope.stpStackModeType);
           			if(stackInitialData !== $scope.stpStackModeType){
           			  switch(selectedStackingOption[0].stpStackText) {
@@ -395,8 +382,8 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
           				case "Standalone":
           				  cliHostNameCmd = $scope.standaloneConfig(cliHostNameCmd);
           				  break;
-                  default:
-                    break;
+						default:
+						  break;
           			  }
           			}else{
                   if($scope.cluster.virtualDomainName && oldClusterDomainName !== $scope.cluster.virtualDomainName){
@@ -412,7 +399,6 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
                      $window.location.href = "http://"+ $scope.switchConfigData.switchIp + "/#/switch";
                    }
                 }
-				
 				if(deviceType.indexOf("CDB") != -1){
 					if($scope.imageON == true){
 						cliHostNameCmd += "do led status " + $scope.ledDayType + " " + $scope.ledHrType + " " +  $scope.ledMinType + "\n";
@@ -423,74 +409,37 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
                     var result = requestRoutingService.getConfigCmdOutput(cliHostNameCmd);
                   	if(result=="" || result.errorResponse.indexOf("MTU will not take effect until the next reload is done")!=-1 ){
                   		notificationService.showNotification(translate('switch_success_msg'),translate('com_config_success_title'),'success');
-          						if(!stackingIsEdited && stackInitialData !== $scope.stpStackModeType){
-                        location.reload();
-          						}
+						if(!stackingIsEdited && stackInitialData !== $scope.stpStackModeType){
+							location.reload();
+						}
                     }else{
                   		notificationService.showNotification(result.errorResponse,translate('com_config_fail_title'),'error');
                   	}
-              			$scope.diableApplyButton=true;
-              			$scope.initGridLoad();
-    					      $scope.clusterConfig();
+					$scope.diableApplyButton=true;
+					$scope.initGridLoad();
+					$scope.clusterConfig();
                     switchInitialData = angular.copy($scope.switchConfigData);
                   },50);
                 }
             }
         };
-		$scope.saveBluetoothConfig = function () {
-			var clibluetoothCmd="";
-			if(deviceType.indexOf("2960C-")===-1 || deviceType.indexOf("2960+48TC-S") === -1){
-				if ($scope.switchConfigData.bluetoothstatus === translate("toggle_on")) {
-					clibluetoothCmd += "staging config bluetooth on \n";
-				} else {
-					clibluetoothCmd += "staging config bluetooth off \n";
-				}
-				 if(clibluetoothCmd!=""){
-					var result = requestRoutingService.getShowCmdOutput(clibluetoothCmd);
-					if(result=="" || (typeof(result) == "string" && result.indexOf("A pool already exists for network") != -1) || (result.hasOwnProperty("errorResponse") && result.errorResponse.indexOf("A pool already exists for network") != -1) ){
-						notificationService.showNotification(translate('switch_success_msg'),translate('com_config_success_title'),'success');
-					}else{
-						if(typeof(result) == "string"){
-							notificationService.showNotification(result,translate('com_config_fail_title'),'error');
-						}else{
-							notificationService.showNotification(result.errorResponse,translate('com_config_fail_title'),'error');
-						}
-					}
-				}
-				$scope.diableblueApplyButton = true;
-				$scope.cancelblueButton = true;
-			}
-		};
-		
-		
-		$scope.cancelBluetoothConfig = function () {
-			$scope.diableApplyButton = true;
-			$scope.cancelblueButton = true;
-			$scope.initGridLoad();   
-		}	
-		
-		$scope.togglebluechange = function(){
-			$scope.diableblueApplyButton = false;
-			$scope.cancelblueButton = false;
-		};
-		
 		$scope.switchmtuSizeOnchange = function(){
 			$scope.diableApplyButton = false;
 		};
         //cancel the changes
         $scope.cancelSwitchConfig = function () {
-        	 $scope.diableApplyButton=true;
-        	 $scope.switchConfigData.hostName=switchInitialData.hostName;
-        	 $scope.switchConfigData.switchIp=switchInitialData.switchIp;
-        	 $scope.switchConfigData.managementVlan=switchInitialData.managementVlan;
-        	 $scope.switchConfigData.mtuSize=switchInitialData.mtuSize;
-        	 $scope.switchConfigData.subnetMask=switchInitialData.subnetMask;
-        	 $scope.switchConfigData.defaultGateway=switchInitialData.defaultGateway;
-        	 $scope.switchConfigData.switchCOAP=switchInitialData.switchCOAP;
-        	 $scope.initGridLoad();
-           $scope.clusterConfig();
-           $scope.stpStackModeType = oldStpStackModeType;
-        };        
+			$scope.diableApplyButton=true;
+			$scope.switchConfigData.hostName=switchInitialData.hostName;
+			$scope.switchConfigData.switchIp=switchInitialData.switchIp;
+			$scope.switchConfigData.managementVlan=switchInitialData.managementVlan;
+			$scope.switchConfigData.mtuSize=switchInitialData.mtuSize;
+			$scope.switchConfigData.subnetMask=switchInitialData.subnetMask;
+			$scope.switchConfigData.defaultGateway=switchInitialData.defaultGateway;
+			$scope.switchConfigData.switchCOAP=switchInitialData.switchCOAP;
+			$scope.initGridLoad();
+			$scope.clusterConfig();
+			$scope.stpStackModeType = oldStpStackModeType;
+        };
         $scope.commonConfirmationSwitch = function() {
             $scope.dlgSwitch = dialogService.dialog({
                 content : translate("msg_redirect_confirmation")+" "+$scope.switchConfigData.switchIp,
@@ -516,9 +465,55 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
            }else{
         	   $scope.saveSwitchConfig();
            }
-        };        
-        /*Controller - Data & Actions For Switch Tab Ends*/
-        /*Controller - Data & Actions For STP Tab Starts*/
+        };
+  /*Controller - Data & Actions For Switch Tab Ends*/
+  /*Blue Tooth Config Page Start*/
+     $scope.loadBlueTooth = function(){
+    	if(deviceType.indexOf("2960C-") === -1 || deviceType.indexOf("2960+48TC-S") === -1 || deviceType.indexOf("2960+-48TC-S") != -1){
+			$scope.diableblueApplyButton=true;
+			$scope.cancelblueButton = true;
+			var bluetoothData = requestRoutingService.getShowCmdOutput("show bluetooth stats");
+			if(bluetoothData.indexOf("BT Interface is Ready") != -1) {
+				$scope.switchConfigData.bluetoothstatus = translate("toggle_on");
+			}else {
+				$scope.switchConfigData.bluetoothstatus = translate("toggle_off");
+			}
+		}
+      }
+      $scope.saveBluetoothConfig = function () {
+			var clibluetoothCmd="";
+			if(deviceType.indexOf("2960C-")===-1 || deviceType.indexOf("2960+48TC-S") === -1 || deviceType.indexOf("2960+-48TC-S") != -1){
+				if ($scope.switchConfigData.bluetoothstatus === translate("toggle_on")) {
+					clibluetoothCmd += "staging config bluetooth on \n";
+				} else {
+					clibluetoothCmd += "staging config bluetooth off \n";
+				}
+				 if(clibluetoothCmd!=""){
+					var result = requestRoutingService.getShowCmdOutput(clibluetoothCmd);
+					if(result=="" || (typeof(result) == "string" && result.indexOf("A pool already exists for network") != -1) || (result.hasOwnProperty("errorResponse") && result.errorResponse.indexOf("A pool already exists for network") != -1) ){
+						notificationService.showNotification(translate('switch_success_msg'),translate('com_config_success_title'),'success');
+					}else{
+						if(typeof(result) == "string"){
+							notificationService.showNotification(result,translate('com_config_fail_title'),'error');
+						}else{
+							notificationService.showNotification(result.errorResponse,translate('com_config_fail_title'),'error');
+						}
+					}
+				}
+				$scope.loadBlueTooth();
+			}
+		};
+		$scope.cancelBluetoothConfig = function () {
+			$scope.diableApplyButton = true;
+			$scope.cancelblueButton = true;
+			$scope.loadBlueTooth();
+		}
+		$scope.togglebluechange = function(){
+			$scope.diableblueApplyButton = false;
+			$scope.cancelblueButton = false;
+		};
+  /*Blue Tooth Config Page Ends*/
+  /*Controller - Data & Actions For STP Tab Starts*/
         /*Default Values*/
         var stpDefaultModeType = "rapid-pvst";
         /*To Identify Edited filed*/
@@ -540,8 +535,13 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
         $scope.disableCancelButton = function () {
             return ($scope.stpModeEdited || $scope.gridEdited) ? false : true;
         };
+      $scope.loadSTP= function(){
         $scope.stpGridValues = stpdataSourceService.getVlanData();
-
+        $timeout(function () {
+        	var stpMode=stpdataSourceService.getStpModeType();
+            $scope.stpModeType = stpMode ? stpMode : stpDefaultModeType;
+            $scope.stpModeModel = angular.copy($scope.stpModeType);
+        }, 1000);
         /*Kendo Grid-Data Values*/
         var hdrTmpbridgePriorityNum=translate("stp_bridgepriority") + " <tooltip helptext='" + translate("help_STP_bridge_priority_number") +"' position='top'></tooltip>";
         $scope.stpInstanceGridOptions = {
@@ -617,6 +617,8 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
             }
         };
         $scope.stpInstancedataSource = kendoGridObject($scope.stpGridValues);
+    }
+
         /*STP Mode Select*/
         $scope.updateStpMode = function () {
             if ( ($scope.stpModeModel) && ($scope.stpModeModel !== $scope.stpModeType)) {
@@ -633,7 +635,8 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
                 stpCliCommand=stpCliCommand+$scope.stpModeType;
                 resultResponse=requestRoutingService.getConfigCmdOutput(stpCliCommand);
                 $timeout(function () {
-                    $scope.stpModeType = stpdataSourceService.getStpModeType() ? stpdataSourceService.getStpModeType() : stpDefaultModeType;
+                	var stpMode=stpdataSourceService.getStpModeType();
+                    $scope.stpModeType = stpMode ? stpMode : stpDefaultModeType;
                     $scope.stpModeModel = angular.copy($scope.stpModeType);
                 }, 50);
                 $scope.stpModeEdited = false;
@@ -645,7 +648,7 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
                 var dataSource = kendoGridObject(updatedData);
                 var grid = angular.element('#stpInstanceGrid').data('kendoGrid');
                 dataSource.read();
-                grid.setDataSource(dataSource);                
+                grid.setDataSource(dataSource);
                 $scope.gridEdited = false;
             }
             if(resultResponse==""){
@@ -670,7 +673,6 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
                 $scope.gridEdited = false;
             }
         };
-
         function kendoGridObject(dataValues) {
             var newOject = new kendo.data.DataSource({
                 pageSize: 10,
@@ -717,12 +719,6 @@ app.register.controller('StpCtrl', ['$scope','$rootScope','$filter', 'gridCrudSe
             });
             return newOject;
         };
-
-        $timeout(function () {
-            $scope.stpModeType = stpdataSourceService.getStpModeType() ? stpdataSourceService.getStpModeType() : stpDefaultModeType;
-            $scope.stpModeModel = angular.copy($scope.stpModeType);
-        }, 1000);        
         /*Controller - Data & Actions For STP Tab Ends*/
-
     }
 ]);
