@@ -3,8 +3,8 @@
  Copyright (c) 2016 by Cisco Systems, Inc.
  All rights reserved.
  */
-app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gridCrudService','requestRoutingService','executeCliCmdService','$timeout','getStringLineService','notificationService','dialogService','validationService',
-	function($scope,$rootScope,$filter,gridCrudService,requestRoutingService,executeCliCmdService,$timeout,getStringLineService,notificationService,dialogService,validationService) {
+app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gridCrudService','requestRoutingService','executeCliCmdService','$timeout','getStringLineService','notificationService','dialogService','validationService','httpServices',
+	function($scope,$rootScope,$filter,gridCrudService,requestRoutingService,executeCliCmdService,$timeout,getStringLineService,notificationService,dialogService,validationService,httpServices) {
 		var translate = $filter("translate");
 		$scope.showStackRestart = ($rootScope.deviceInfo.stackingInfo.type === "STACK");
 		$scope.statusMsg="";
@@ -16,6 +16,8 @@ app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gr
 		$scope.disableTrace = true; 
 		$scope.diableDiagnostic = true;			
 		$rootScope.portNumIdentity = "";
+		$scope.switchDisplayreboot = false;
+		$scope.switchDisplayfindSwitch = false;
 		// Ping validation
 		var pingValidations = angular.element("#pingForm").kendoValidator({
 			rules: {
@@ -40,13 +42,26 @@ app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gr
 			
 		}
 		$scope.findSwitchLoader = function(tab){
-			if(tab === 'findswitch'){				
+			if(tab === 'ping'){
+				$scope.loadInterfaces();
+			}
+			if(tab === 'traceRoute'){
+			
+			}
+			if(tab === 'diagnostic'){
+				$scope.diagnosticResults();
+			}
+			if(tab === 'findswitch'){
+				$scope.switchDisplayreboot = false;
+				$scope.switchDisplayfindSwitch = true;
 				$timeout(function(){
 					$rootScope.switchfinder = true;
 					$rootScope.showRestartBtn = false;
 				},200)
 			}
-			if(tab === 'reboot'){				
+			if(tab === 'reboot'){
+				$scope.switchDisplayreboot = true;
+				$scope.switchDisplayfindSwitch = false;
 				$timeout(function(){
 					$rootScope.switchfinder = false;
 					$rootScope.showRestartBtn = true;
@@ -133,9 +148,9 @@ app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gr
 			if($rootScope.deviceInfo.type.indexOf("CDB")!=-1){
                                 var result = requestRoutingService.getShowCmdOutput("staging network\n");
 				if(result == ""){
-					notificationService.showNotification(translate('connect_to_controller_successful'),translate('connect_to_controller_title'),'success');
+					notificationService.showNotification(translate('connect_to_controller_success_msg'),translate('com_config_success_msg'),'success');
 				} else {
-					notificationService.showNotification(result.errorResponse,translate('connect_to_controller_title'),'error');
+					notificationService.showNotification(result.errorResponse,translate('com_config_fail_title'),'error');
 				}
                         }
                 });
@@ -306,6 +321,9 @@ app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gr
 				}
 			}
 		}).data("kendoValidator");
+	   function isNumeric(n) {
+		  return !isNaN(parseFloat(n)) && isFinite(n);
+	   }
        $scope.startTraceRoute= function(evt) {
           evt=evt.target;
           if(traceRouteValidations.validate()){
@@ -314,7 +332,7 @@ app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gr
           $scope.isTraceRouteGrid = false;
           $timeout(function(){
       		  var strCLIOutput = deviceCommunicator.getExecCmdOutput("traceroute "+$scope.traceRouteName+"\n");
-	          angular.element(evt).button('reset');
+      		  angular.element(evt).button('reset');
 	          $scope.showTick = true;
 	           var arrTraceRouteDetails = new Array();
 	           var arrWords = new Array();
@@ -325,28 +343,39 @@ app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gr
 	           var strLines = getStringLineService.getLines(strCLIOutput,LINE_INDEX);
 	           if (strLines != null) {
 	              for (var i=0; i<strLines.length; i++) {
-	                      var strLine = strLines[i];
+	                      var strLine = strLines[i].trim();
 	                      if(strLine.indexOf(")")!=-1){
 	                          arrWords  = strLine.split(")");
-	                          arrTTL    = arrWords[0].split(" ");
-	                          arrWords1 = arrWords[0].split("(");
-	                          arrDelays = arrWords[1].split(" ");
-	                          var items = {
-	                        		"hopCount"     : arrTTL[2],
-	                          		"hop"          : arrWords1[1],
-	                          		"roundTrip1"   : arrDelays[1],
-	                          		"roundTrip2"   : arrDelays[3],
-	                          		"roundTrip3"   : arrDelays[5]
-	                          };
-	                          arrTraceRouteDetails.push(items);
+	                          arrTTL    = arrWords[0].trim().split(" ");
+	                          arrWords1 = arrWords[0].trim().split("(");
+	                          arrDelays = arrWords[1].trim().split(" ");
+	                          if(isNumeric(arrTTL[0])){
+	                        	  var items = {
+	  	                        		"hopCount"     : arrTTL[0],
+	  	                          		"hop"          : arrTTL[1]+" ("+arrWords1[1]+")",
+	  	                          		"roundTrip1"   : arrDelays[0],
+	  	                          		"roundTrip2"   : arrDelays[2],
+	  	                          		"roundTrip3"   : arrDelays[4]
+	  	                          };
+	  	                          arrTraceRouteDetails.push(items);
+	                          }else{
+	                        	  var items = {
+		  	                        		"hopCount"     : "",
+		  	                        		"hop"          : arrTTL[0]+" ("+arrWords1[1]+")",
+		  	                          		"roundTrip1"   : arrDelays[0],
+		  	                          		"roundTrip2"   : arrDelays[2],
+		  	                          		"roundTrip3"   : arrDelays[4]
+		  	                      };
+		  	                      arrTraceRouteDetails.push(items);
+	                          }
 	                       } else{
 	                    	   arrWords = strLine.split(" ");
 	                       	   var items1 = {
-	                    			"hopCount"     : arrWords[2],
-	                           		"hop"          : arrWords[3],
-	                           		"roundTrip1"   : arrWords[4],
-	                           		"roundTrip2"   : arrWords[6],
-	                           		"roundTrip3"   : arrWords[8]
+	                    			"hopCount"     : arrWords[0],
+	                           		"hop"          : arrWords[1],
+	                           		"roundTrip1"   : arrWords[2],
+	                           		"roundTrip2"   : arrWords[4],
+	                           		"roundTrip3"   : arrWords[6]
 	                           };
 	                           arrTraceRouteDetails.push(items1);
 	                       }
@@ -401,25 +430,30 @@ app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gr
 	                   },
 	                   columns : [{
 	                           field : "hopCount",
-	                           title : translate("trouble_shoot_traceroute_hop_ttl")
+	                           title : translate("trouble_shoot_traceroute_hop_ttl"),
+	                           width : "15%"
 	                   },{
                            	   field : "hop",
-                           	   title : translate("trouble_shoot_traceroute_hop")
+                           	   title : translate("trouble_shoot_traceroute_hop"),
+                           	   width : "40%"
 	                   },{
 	                           field : "roundTrip1",
-	                           title : translate("trouble_shoot_traceroute_roundtrip")
+	                           title : translate("trouble_shoot_traceroute_roundtrip"),
+	                           width : "15%"
 	                   }, {
 	                           field : "roundTrip2",
-	                           title : translate("trouble_shoot_traceroute_roundtrip")
+	                           title : translate("trouble_shoot_traceroute_roundtrip"),
+	                           width : "15%"
 	                   }, {
 	                           field : "roundTrip3",
-	                           title : translate("trouble_shoot_traceroute_roundtrip")
+	                           title : translate("trouble_shoot_traceroute_roundtrip"),
+	                           width : "15%"
 	                   }]
 	           };
 	        },50)
        }
        }
- //Start Diagnostic code
+		//Start Diagnostic code
        //Hiding the diagnostics tab if the device platform is 2960 plus and the type contains "-S" at the end. -S indicates lanlite for 2960 plus platform
        $scope.showDiagnostic=true; 
       if($rootScope.deviceInfo.type === "WS-C2960+48TC-S" || $rootScope.deviceInfo.type === "WS-C2960+-48TC-S"){
@@ -467,6 +501,7 @@ app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gr
 		});
 		 $scope.startTests= function(popup) {
 		    	popup.close();
+		    	var diagnosticCLI="",hiddenCLI="";
 		    	var formToSubmit = document.getElementById("diagnosticForm");
 		    	 if(($rootScope.deviceInfo.type.indexOf("2960X")!=-1 && ($rootScope.deviceInfo.type != "WS-C2960X-24PSQ-L" &&
                                                 $rootScope.deviceInfo.type != "WS-C2960X-48TS-LL" &&
@@ -474,23 +509,42 @@ app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gr
 					|| $rootScope.deviceInfo.type.indexOf("2960XR")!=-1
 					|| $rootScope.deviceInfo.type == "WS-C3560CX-12PD-S" || $rootScope.deviceInfo.type == "WS-C3560CX-8XPD-S" ){
 						if($scope.diagnosticTest==="basic"){
-		       		        formToSubmit.action = "/level/15/exec/-/diagnostic/start/switch/"+$rootScope.deviceInfo.masterId+"/test/basic";
+							diagnosticCLI = "/level/15/exec/-/diagnostic/start/switch/"+$rootScope.deviceInfo.masterId+"/test/basic";
+							hiddenCLI = "diagnostic start switch "+$rootScope.deviceInfo.masterId+" test basic";
 			    		} else if($scope.diagnosticTest==="all"){
-			    			 formToSubmit.action = "/level/15/exec/-/diagnostic/start/switch/"+$rootScope.deviceInfo.masterId+"/test/all";
+			    			diagnosticCLI = "/level/15/exec/-/diagnostic/start/switch/"+$rootScope.deviceInfo.masterId+"/test/all";
+			    			hiddenCLI = "diagnostic start switch "+$rootScope.deviceInfo.masterId+" test all";
 			    		} else{
-			    			 formToSubmit.action = "/level/15/exec/-/diagnostic/start/switch/"+$rootScope.deviceInfo.masterId+"/test/non-disruptive";
+			    			diagnosticCLI = "/level/15/exec/-/diagnostic/start/switch/"+$rootScope.deviceInfo.masterId+"/test/non-disruptive";
+			    			hiddenCLI = "diagnostic start switch "+$rootScope.deviceInfo.masterId+" test non-disruptive";
 			    		}
 		    	 }else{
 		    		 if($scope.diagnosticTest==="basic"){
-		    		      formToSubmit.action = "/level/15/exec/-/diagnostic/start/test/basic";
+		    			 diagnosticCLI = "/level/15/exec/-/diagnostic/start/test/basic";
+		    			 hiddenCLI = "diagnostic start test basic";
 		    		 } else if($scope.diagnosticTest==="all"){
-		    		      formToSubmit.action = "/level/15/exec/-/diagnostic/start/test/all";
+		    			 diagnosticCLI = "/level/15/exec/-/diagnostic/start/test/all";
+		    			 hiddenCLI = "diagnostic start test all";
 		    		 } else{
-		    			  formToSubmit.action = "/level/15/exec/-/diagnostic/start/test/non-disruptive";
+		    			 diagnosticCLI = "/level/15/exec/-/diagnostic/start/test/non-disruptive";
+		    			 hiddenCLI = "diagnostic start test non-disruptive";
 		    		 }
-		    	 }
-		    	formToSubmit.submit();
-		    	$scope.diagnosticResults();
+		    	}
+		        $scope.getConfigureToken = function(){
+        			 var url = diagnosticCLI;
+        			 var result = httpServices.httpGetMethod(url);
+        			 var token = result.slice(result.search("csrf_token VALUE=")+18, result.search("csrf_token VALUE=")+18+40)
+		             return token;
+		        };
+	            var token = $scope.getConfigureToken();
+		        var url=diagnosticCLI;
+		        var data = 'hidden_command='+hiddenCLI+'&csrf_token='+token+'&CMD=CR';
+		        var result=httpServices.httpPostMethod(url,data)
+		        notificationService.showNotification("",translate('diagnostic_success_msg'),'success');
+		    	$timeout(function(){
+		    	   $scope.diagnosticResults();
+		    	},500);
+		    	$scope.diableDiagnostic = true;
 		 }
 	    $scope.diagnosticResults= function() {
 	    	 var showDiagnosticResult = "";
@@ -618,10 +672,8 @@ app.register.controller('troubleShootCtrl', ['$scope','$rootScope','$filter','gr
 	    		}
 	    	}
 	    }
-	    $scope.diagnosticResults();
       }  
-//End Diagnostic	    
-		
+	  //End Diagnostic
 		// find switch tab
 		$scope.findSwitch = function (){
 			var findCli="led beacon";
